Page 28 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 28

Home

    Some writers believed that the Templars believed in
    a god of good and a god of evil but chose to serve the
    god of evil (Lucifer) because they thought him to be
    more powerful and able to make them rich. Nesta H.

    Their most fervent worship was addressed to this god
    of evil, who alone could enrich them. "They said with the
    Luciferians: The elder son of God, Satanael or Lucifer
    alone has a right to the homage of mortals; Jesus his
    younger brother does not deserve this honour."

    The Templars not only became international bankers
    in their day, they also supported uprisings against
    existing governments to a point of threatening world
    wide revolution. As we progress to our study of the
    Mystery Babylon of Revelation, we will see that history
    repeats itself.

    It has been tragic for the human race "that secret

    operating in secrecy, have been able to involve large
    numbers of well-meaning followers at the lower levels

    who, in working for the goals of the organization, were
    paving the way for their own destruction. This pattern is
    more evident in the twentieth century than at any other

    time in history.
    Just as there existed secret and subversive sects

    23

    Secret Societies

    contained nothing but perfect orthodoxy. The inside or

    secret profession was anti-Christian.

    Webster gives the following quotation:

    societies, with a small number of leaders always

    working against Christianity and orthodox Judaism, there